==> moodle-3.11.14.zip: moodle/h5p/h5plib/v124/joubel/editor/language/es-mx.js <==
H5PEditor.language.core = {
  missingTranslation: '[Falta la traducción :key]',
  loading: 'Cargando, por favor espera...',
  selectLibrary: 'Selecciona la librería que quieres usar con tu contenido.',
  unknownFieldPath: 'No se puede encontrar ":path".',
  notImageField: '":path" no es una imagen.',
  notImageOrDimensionsField: '":path" no es una imagen o un campo de dimensiones.',
  requiredProperty: 'La :property es requerida y debe tener un valor.',
  onlyNumbers: 'El valor de :property solo puede contener números.',
  illegalDecimalNumber: ':property solamente puede contener números con un máximo de :decimals decimales.',
  exceedsMax: 'El valor de :property excede el máximo de :max.',
  listExceedsMax: 'La lista excede el máximo de :max elementos.',
  belowMin: 'El valor de :property excede el mínimo de :min.',
  listBelowMin: 'La lista necesita al menos :min elementos para que el contenido funcione adecuadamente.',
  outOfStep: 'El valor de :property solo puede ser cambiado en pasos de :step.',
  add: 'Añadir',
  addFile: 'Añadir archivo',
  removeFile: 'Eliminar archivo',
  confirmRemoval: '¿Estás seguro que quieres eliminar este :type?',
  removeImage: 'Eliminar imagen',
  confirmImageRemoval: 'Esto eliminará la imagen. ¿Seguro que desea continuar?',
  changeFile: 'Cambiar archivo',
  changeLibrary: 'Cambiar el tipo de contenido',
  semanticsError: 'Error en semántica: :error',
  missingProperty: 'El campo :index no contiene la propiedad :property.',
  expandCollapse: 'Expandir/Colapsar',
  addEntity: 'Añadir :entity',
  tooLong: 'El valor del campo es demasiado largo, debería contener un máximo de :max letras.',
  invalidFormat: 'El valor del campo contiene un formato no válido o caracteres prohibidos.',
  confirmChangeLibrary: 'Al hacer esto perderás todo el trabajo realizado con el tipo de contenido actual. ¿Estás seguro de que quieres cambiar el tipo de contenido?',
  commonFields: 'Parámetros y textos',
  commonFieldsDescription: 'Aquí puedes editar parámetros o traducir textos utilizados en este contenido.',
  uploading: 'Subiendo, por favor espera...',
  noFollow: 'No se puede seguir el campo ":path".',
  editCopyright: 'Editar copyright',
  close: 'Cerrar',
  tutorial: 'Tutorial',
  editMode: 'Modo de edición',
  listLabel: 'Lista',
  uploadError: 'Error en la subida del archivo',
  fileToLarge: 'El archivo que intenta subir es demasiado grande.',
  unknownFileUploadError: 'Error de carga de archivo desconocido',
  noSemantics: 'Error, no se ha podido cargar el formato del tipo de contenido.',
  editImage: 'Editar imagen',
  saveLabel: 'Guardar',
  cancelLabel: 'Cancelar',
  resetToOriginalLabel: 'Restablecer el original',
  loadingImageEditor: 'Cargando editor de imagen, por favor espere...',
  selectFiletoUpload: 'Seleccione el archivo a subir',
  or: 'o',
  enterAudioUrl: 'Introduzca la URL del origen del audio',
  enterVideoUrl: 'Introduzca la URL del origen del video o link en Youtube',
  enterAudioTitle: 'Pegue el link u otra fuente de audio',
  enterVideoTitle: 'Peque el link de Youtube o la URL de la fuente del video',
  uploadAudioTitle: 'Subir archivo de audio',
  uploadVideoTitle: 'Subir archivo de video',
  addVideoDescription: 'H5P soporta todas las fuentes de vídeo externas con formato mp4, webm u ogv, como Vimeo Pro, y tiene soporte para enlaces de YouTube.',
  insert: 'Insertar',
  cancel: 'Cancelar',
  height: 'altura',
  width: 'ancho',
  textField: 'campo de texto',
  numberField: 'campo numérico',
  orderItemUp: 'Ordenar elemento arriba',
  orderItemDown: 'Ordenar elemento abajo',
  removeItem: 'Eliminar elemento',
  hubPanelLabel: 'Seleccionar tipo de contenido',
  importantInstructions: 'Instrucciones importantes',
  showImportantInstructions: 'Mostrar instrucciones',
  hideImportantInstructions: 'Ocultar instrucciones importantes',
  hide: 'Ocultar',
  example: 'Ejemplo',
  createContentTabLabel: 'Crear Contenido',
  uploadTabLabel: 'Subir',
  uploadPlaceholder: 'Ningún archivo seleccionado',
  uploadInstructionsTitle: 'Subir un archivo H5P.',
  uploadInstructionsContent: 'Usted puede comenzar con ejemplos de <a href="https://h5p.org/content-types-and-applications" target="blank">H5P.org</a>.',
  uploadFileButtonLabel: 'Subir un archivo',
  uploadFileButtonChangeLabel: 'Cambiar archivo',
  uploadingThrobber: 'Subiendo ahora...',
  uploadSuccess: ':title se subió correctamente!',
  unableToInterpretError: 'No se puede interpretar la respuesta.',
  unableToInterpretSolution: 'Por favor revise su bitácora de errores.',
  h5pFileWrongExtensionTitle: 'El archivo elegido no se puede subir',
  h5pFileWrongExtensionContent: 'Solo se permiten archivos con la extensión .h5p.',
  h5pFileValidationFailedTitle: 'No se puede validar el archivo H5P.',
  h5pFileValidationFailedContent: 'Asegúrese de que el H5P cargado contiene contenido H5P válido. H5P Los archivos que contienen sólo bibliotecas deben cargarse a través de la página Bibliotecas H5P.',
  h5pFileUploadServerErrorTitle: 'El archivo H5P no se ha podido cargar',
  h5pFileUploadServerErrorContent: 'Ocurrió un error inesperado. Compruebe el registro de errores del servidor para obtener más detalles.',
  contentTypeSectionAll: 'Todos los tipos de contenidos',
  searchResults: 'Resultados de búsqueda',
  contentTypeSearchFieldPlaceholder: 'Buscar tipos de contenido',
  contentTypeInstallButtonLabel: 'Instalar',
  contentTypeInstallingButtonLabel: 'Instalando',
  contentTypeUseButtonLabel: 'Usar',
  contentTypeDetailButtonLabel: 'Detalles',
  contentTypeUpdateButtonLabel: 'Actualizar',
  contentTypeUpdatingButtonLabel: 'Actualizando',
  contentTypeGetButtonLabel: 'Obtener',
  contentTypeBackButtonLabel: 'Atrás',
  contentTypeIconAltText: 'Icono',
  contentTypeInstallSuccess: ':contentType instalado con éxito!',
  contentTypeUpdateSuccess: ':contentType actualizado con éxito!',
  contentTypeInstallError: ':contentType no puede ser instalado. Póngase en contacto con su administrador.',
  contentTypeLicensePanelTitle: 'Licencia',
  contentTypeDemoButtonLabel: 'Demo de Contenido',
  numResults: ':num resultados',
  show: 'Mostrar',
  recentlyUsedFirst: 'Usado recientemente Primero',
  popularFirst: 'Popular primero',
  newestFirst: 'Lo mas nuevo primero',
  aToZ: 'A a la Z',
  noResultsFound: 'No se han encontrado resultados',
  noResultsFoundDesc: 'No hay ningún tipo de contenido que coincida con sus criterios de búsqueda.',
  readMore: 'Leer más',
  readLess: 'Leer menos',
  contentTypeOwner: 'Por :owner',
  contentTypeUnsupportedApiVersionTitle: 'Este tipo de contenido requiere una nueva versión del core',
  contentTypeUnsupportedApiVersionContent: 'Póngase en contacto con el responsable del sistema para obtener las actualizaciones necesarias.',
  contentTypeUpdateAvailable: 'Actualización disponible',
  contentTypeRestricted: 'Tipo de contenido restringido',
  contentTypeRestrictedDesc: 'El uso de este tipo de contenido ha sido restringido por un administrador.',
  contentTypeNotInstalled: 'Tipo de contenido no instalado',
  contentTypeNotInstalledDesc: 'No tiene permiso para instalar tipos de contenido.',
  theContentType: 'el tipo de contenido',
  currentMenuSelected: 'selección actual',
  errorCommunicatingHubTitle: 'No se puede comunicar con el hub.',
  errorCommunicatingHubContent: 'Ha ocurrido un error. Por favor, inténtelo de nuevo.',
  warningNoContentTypesInstalled: 'No tiene ningún tipo de contenido instalado.',
  warningChangeBrowsingToSeeResults: 'Click <em>Todos</em> para obtener la lista de todos los tipos de contenido que puede instalar .',
  warningUpdateAvailableTitle: 'Una nueva versión de :contentType está disponible.',
  warningUpdateAvailableBody: 'Actualización a la última versión para una experiencia mejorada.',
  licenseDescription: 'Algunas de las características de esta licencia se indican a continuación. Haga clic en el icono de información de arriba para leer el texto original de la licencia.',
  licenseModalTitle: 'Detalles de la Licencia',
  licenseModalSubtitle: 'Seleccione una licencia para ver información sobre el uso adecuado',
  licenseUnspecified: 'Sin especificar',
  licenseCanUseCommercially: 'Uso comercial',
  licenseCanModify: 'Se puede modificar',
  licenseCanDistribute: 'Se puede distribuir',
  licenseCanSublicense: 'Se puede sublicenciar',
  licenseCanHoldLiable: 'Se puede declarar responsable',
  licenseCannotHoldLiable: 'No puede declararse responsable',
  licenseMustIncludeCopyright: 'Debe incluir copyright',
  licenseMustIncludeLicense: 'Debe incluir licencia',
  licenseFetchDetailsFailed: 'Fallo en la obtención de los detalles de la licencia',
  imageLightboxTitle: 'Imágenes',
  imageLightBoxProgress: ':num de :total',
  nextImage: 'Siguiente imagen',
  previousImage: 'Imagen anterior ',
  screenshots: 'Capturas de pantalla',
  reloadButtonLabel: 'Recargar',
  videoQuality: 'Etiqueta de calidad de vídeo',
  videoQualityDescription: 'Esta etiqueta ayuda al usuario a identificar la calidad actual del vídeo. Por ejemplo, 1080p, 720p, HD o móvil',
  videoQualityDefaultLabel: 'Calidad :index',
  noContentTypesAvailable: 'No hay tipos de contenido disponibles',
  noContentTypesAvailableDesc: 'Su sitio tiene dificultades para conectarse a H5P.org y para listar los tipos de contenido disponibles.',
  contentTypeCacheOutdated: 'Lista de tipos de contenido obsoleta',
  contentTypeCacheOutdatedDesc: 'Su sitio tiene dificultades para conectarse a H5P.org para comprobar si hay actualizaciones del tipo de contenido. Es posible que no pueda actualizar o instalar nuevos tipos de contenido.',
  tryAgain: 'Inténtelo de nuevo',
  getHelp: 'Obtener ayuda',
  untitled: 'Sin título :libraryTitle',
  title: 'Título',
  metadata: 'Metadatos',
  addTitle: 'Añadir título',
  usedForSearchingReportsAndCopyrightInformation: 'Utilizado para búsquedas, informes e información de derechos de autor',
  metadataSharingAndLicensingInfo: 'Metadatos (información sobre uso compartido y licencias)',
  fillInTheFieldsBelow: 'Rellene los siguientes campos',
  saveMetadata: 'Guardar metadatos',
  addAuthor: 'Guardar autor',
  confirmRemoveAuthor: '¿Está seguro de que desea eliminar a este autor?',
  addNewChange: 'Añadir nuevo cambio',
  confirmDeleteChangeLog: '¿Está seguro de que desea borrar esta entrada del registro de cambios?',
  changelogDescription: 'Algunas licencias requieren que los cambios realizados en la obra original o los derivados se registren y visualicen. Usted puede registrar sus cambios aquí por razones de licencia o simplemente para permitirse a usted y a otros mantener un registro de los cambios realizados en este contenido.',
  logThisChange: 'Registrar este cambio',
  newChangeHasBeenLogged: 'Se ha registrado un nuevo cambio',
  loggedChanges: 'Cambios registrados',
  noChangesHaveBeenLogged: 'No se ha registrado ningún cambio',
  errorHeader: 'Se ha producido un error',
  errorCalculatingMaxScore: 'No se pudo calcular la puntuación máxima para este contenido. La puntuación máxima se supone que es 0. Póngse en contacto con su administrador si esto no es correcto.',
  maxScoreSemanticsMissing: 'No se pudo encontrar la semántica esperada en el contenido.',
  copyButton: 'Copiar',
  copiedButton: 'Copiado',
  pasteButton: 'Pegar',
  pasteAndReplaceButton: 'Pegar y Reemplazar',
  pasteContent: 'Reemplazar contenido',
  confirmPasteContent: 'Al hacer esto usted reemplazará el contenido actual con el contenido de su portapapeles. El contenido actual se perderá. ¿Está seguro de que quiere continuar?',
  confirmPasteButtonText: 'Reemplazar contenido',
  copyToClipboard: 'Copiar el contenido H5P al portapapeles',
  copiedToClipboard: 'El contenido se ha copiado al portapapeles',
  pasteFromClipboard: 'Pegar el contenido H5P del portapapeles',
  pasteAndReplaceFromClipboard: 'Reemplazar el contenido existente con contenido H5P del portapapeles',
  pasteNoContent: 'Ningún contenido H5P content en el portapapeles',
  pasteError: 'No se puede pegar desde el portapapeles',
  pasteContentNotSupported: 'The content in the H5P clipboard is not supported in this context',
  pasteContentRestricted: 'The content in the clipboard has been restricted on this site',
  pasteTooOld: 'The content in the H5P clipboard is of a lower version (:clip) than what is supported in this context (:local), if possible try to have the content you want to paste upgraded, copy it again and try pasting it here.',
  pasteTooNew: 'The content in the H5P clipboard is of a higher version (:clip) than what is supported in this context (:local), if possible try to have this content upgraded first, and then try pasting the content here again.',
  ok: 'OK',
  avTablistLabel: 'Insertar usando',
  tabTitleBasicFileUpload: 'Subir archivo',
  tabTitleInputLinkURL: 'Enlace/URL',
  errorTooHighVersion: 'Los parámetros contienen %used mientras que solamente %supported o anteriores están soportados.',
  errorNotSupported: 'Los parámetros contienen %used que no está soportado.',
  errorParamsBroken: 'Los parámetros están rotos.',
  libraryMissing: 'Falta la biblioteca requerida %lib.',
  scriptMissing: 'No se pudo cargar el script de actualizaciones para %lib.',
  language: 'Idioma',
  noLanguagesSupported: 'No hay idiomas soportados',
  changeLanguage: '¿Cambiar el idioma a :language?',
  thisWillPotentially: 'Esto potencialmente restablecerá todo el texto y las traducciones. No puedes deshacer esto. El contenido en sí no será cambiado. ¿Desea proceder?',
  notAllTextsChanged: 'No todos los textos fueron cambiados, solo hay una cobertura parcial para :language.',
  contributeTranslations: 'Si desea completar la traducción para :language, puede obtener información sobre <a href=":url" target="_new"> contribuir con traducciones al H5P </a>',
  unknownLibrary: 'Desafortunadamente, el tipo de contenido seleccionado \'%lib\' no está instalado en este sistema.',
  proceedButtonLabel: 'Proceder a guardar',
  enterFullscreenButtonLabel: 'Ir a pantalla completa',
  exitFullscreenButtonLabel: 'Salir de pantalla completa',
};

==> moodle-4.1.6.zip: moodle/h5p/h5plib/v124/joubel/editor/language/es-mx.js <==
H5PEditor.language.core = {
  missingTranslation: '[Falta la traducción :key]',
  loading: 'Cargando, por favor espera...',
  selectLibrary: 'Selecciona la librería que quieres usar con tu contenido.',
  unknownFieldPath: 'No se puede encontrar ":path".',
  notImageField: '":path" no es una imagen.',
  notImageOrDimensionsField: '":path" no es una imagen o un campo de dimensiones.',
  requiredProperty: 'La :property es requerida y debe tener un valor.',
  onlyNumbers: 'El valor de :property solo puede contener números.',
  illegalDecimalNumber: ':property solamente puede contener números con un máximo de :decimals decimales.',
  exceedsMax: 'El valor de :property excede el máximo de :max.',
  listExceedsMax: 'La lista excede el máximo de :max elementos.',
  belowMin: 'El valor de :property excede el mínimo de :min.',
  listBelowMin: 'La lista necesita al menos :min elementos para que el contenido funcione adecuadamente.',
  outOfStep: 'El valor de :property solo puede ser cambiado en pasos de :step.',
  add: 'Añadir',
  addFile: 'Añadir archivo',
  removeFile: 'Eliminar archivo',
  confirmRemoval: '¿Estás seguro que quieres eliminar este :type?',
  removeImage: 'Eliminar imagen',
  confirmImageRemoval: 'Esto eliminará la imagen. ¿Seguro que desea continuar?',
  changeFile: 'Cambiar archivo',
  changeLibrary: 'Cambiar el tipo de contenido',
  semanticsError: 'Error en semántica: :error',
  missingProperty: 'El campo :index no contiene la propiedad :property.',
  expandCollapse: 'Expandir/Colapsar',
  addEntity: 'Añadir :entity',
  tooLong: 'El valor del campo es demasiado largo, debería contener un máximo de :max letras.',
  invalidFormat: 'El valor del campo contiene un formato no válido o caracteres prohibidos.',
  confirmChangeLibrary: 'Al hacer esto perderás todo el trabajo realizado con el tipo de contenido actual. ¿Estás seguro de que quieres cambiar el tipo de contenido?',
  commonFields: 'Parámetros y textos',
  commonFieldsDescription: 'Aquí puedes editar parámetros o traducir textos utilizados en este contenido.',
  uploading: 'Subiendo, por favor espera...',
  noFollow: 'No se puede seguir el campo ":path".',
  editCopyright: 'Editar copyright',
  close: 'Cerrar',
  tutorial: 'Tutorial',
  editMode: 'Modo de edición',
  listLabel: 'Lista',
  uploadError: 'Error en la subida del archivo',
  fileToLarge: 'El archivo que intenta subir es demasiado grande.',
  unknownFileUploadError: 'Error de carga de archivo desconocido',
  noSemantics: 'Error, no se ha podido cargar el formato del tipo de contenido.',
  editImage: 'Editar imagen',
  saveLabel: 'Guardar',
  cancelLabel: 'Cancelar',
  resetToOriginalLabel: 'Restablecer el original',
  loadingImageEditor: 'Cargando editor de imagen, por favor espere...',
  selectFiletoUpload: 'Seleccione el archivo a subir',
  or: 'o',
  enterAudioUrl: 'Introduzca la URL del origen del audio',
  enterVideoUrl: 'Enter video URL',
  enterAudioTitle: 'Pegue el link u otra fuente de audio',
  enterVideoTitle: 'Peque el link de Youtube o la URL de la fuente del video',
  uploadAudioTitle: 'Subir archivo de audio',
  uploadVideoTitle: 'Subir archivo de video',
  addVideoDescription: 'H5P supports all external video sources formatted as mp4, webm or ogv, like Vimeo Pro, and has support for YouTube and Panopto links.',
  insert: 'Insertar',
  cancel: 'Cancelar',
  height: 'altura',
  width: 'ancho',
  textField: 'campo de texto',
  numberField: 'campo numérico',
  orderItemUp: 'Ordenar elemento arriba',
  orderItemDown: 'Ordenar elemento abajo',
  removeItem: 'Eliminar elemento',
  hubPanelLabel: 'Seleccionar tipo de contenido',
  importantInstructions: 'Instrucciones importantes',
  showImportantInstructions: 'Mostrar instrucciones',
  hideImportantInstructions: 'Ocultar instrucciones importantes',
  hide: 'Ocultar',
  example: 'Ejemplo',
  createContentTabLabel: 'Crear Contenido',
  uploadTabLabel: 'Subir',
  uploadPlaceholder: 'Ningún archivo seleccionado',
  uploadInstructionsTitle: 'Subir un archivo H5P.',
  uploadInstructionsContent: 'Usted puede comenzar con ejemplos de <a href="https://h5p.org/content-types-and-applications" target="blank">H5P.org</a>.',
  uploadFileButtonLabel: 'Subir un archivo',
  uploadFileButtonChangeLabel: 'Cambiar archivo',
  uploadingThrobber: 'Subiendo ahora...',
  uploadSuccess: ':title se subió correctamente!',
  unableToInterpretError: 'No se puede interpretar la respuesta.',
  unableToInterpretSolution: 'Por favor revise su bitácora de errores.',
  h5pFileWrongExtensionTitle: 'El archivo elegido no se puede subir',
  h5pFileWrongExtensionContent: 'Solo se permiten archivos con la extensión .h5p.',
  h5pFileValidationFailedTitle: 'No se puede validar el archivo H5P.',
  h5pFileValidationFailedContent: 'Asegúrese de que el H5P cargado contiene contenido H5P válido. H5P Los archivos que contienen sólo bibliotecas deben cargarse a través de la página Bibliotecas H5P.',
  h5pFileUploadServerErrorTitle: 'El archivo H5P no se ha podido cargar',
  h5pFileUploadServerErrorContent: 'Ocurrió un error inesperado. Compruebe el registro de errores del servidor para obtener más detalles.',
  contentTypeSectionAll: 'Todos los tipos de contenidos',
  searchResults: 'Resultados de búsqueda',
  contentTypeSearchFieldPlaceholder: 'Buscar tipos de contenido',
  contentTypeInstallButtonLabel: 'Instalar',
  contentTypeInstallingButtonLabel: 'Instalando',
  contentTypeUseButtonLabel: 'Usar',
  contentTypeDetailButtonLabel: 'Detalles',
  contentTypeUpdateButtonLabel: 'Actualizar',
  contentTypeUpdatingButtonLabel: 'Actualizando',
  contentTypeGetButtonLabel: 'Obtener',
  contentTypeBackButtonLabel: 'Atrás',
  contentTypeIconAltText: 'Icono',
  contentTypeInstallSuccess: ':contentType instalado con éxito!',
  contentTypeUpdateSuccess: ':contentType actualizado con éxito!',
  contentTypeInstallError: ':contentType no puede ser instalado. Póngase en contacto con su administrador.',
  contentTypeLicensePanelTitle: 'Licencia',
  contentTypeDemoButtonLabel: 'Demo de Contenido',
  numResults: ':num resultados',
  show: 'Mostrar',
  recentlyUsedFirst: 'Usado recientemente Primero',
  popularFirst: 'Popular primero',
  newestFirst: 'Lo mas nuevo primero',
  aToZ: 'A a la Z',
  noResultsFound: 'No se han encontrado resultados',
  noResultsFoundDesc: 'No hay ningún tipo de contenido que coincida con sus criterios de búsqueda.',
  readMore: 'Leer más',
  readLess: 'Leer menos',
  contentTypeOwner: 'Por :owner',
  contentTypeUnsupportedApiVersionTitle: 'Este tipo de contenido requiere una nueva versión del core',
  contentTypeUnsupportedApiVersionContent: 'Póngase en contacto con el responsable del sistema para obtener las actualizaciones necesarias.',
  contentTypeUpdateAvailable: 'Actualización disponible',
  contentTypeRestricted: 'Tipo de contenido restringido',
  contentTypeRestrictedDesc: 'El uso de este tipo de contenido ha sido restringido por un administrador.',
  contentTypeNotInstalled: 'Tipo de contenido no instalado',
  contentTypeNotInstalledDesc: 'No tiene permiso para instalar tipos de contenido.',
  theContentType: 'el tipo de contenido',
  currentMenuSelected: 'selección actual',
  errorCommunicatingHubTitle: 'No se puede comunicar con el hub.',
  errorCommunicatingHubContent: 'Ha ocurrido un error. Por favor, inténtelo de nuevo.',
  warningNoContentTypesInstalled: 'No tiene ningún tipo de contenido instalado.',
  warningChangeBrowsingToSeeResults: 'Click <em>Todos</em> para obtener la lista de todos los tipos de contenido que puede instalar .',
  warningUpdateAvailableTitle: 'Una nueva versión de :contentType está disponible.',
  warningUpdateAvailableBody: 'Actualización a la última versión para una experiencia mejorada.',
  licenseDescription: 'Algunas de las características de esta licencia se indican a continuación. Haga clic en el icono de información de arriba para leer el texto original de la licencia.',
  licenseModalTitle: 'Detalles de la Licencia',
  licenseModalSubtitle: 'Seleccione una licencia para ver información sobre el uso adecuado',
  licenseUnspecified: 'Sin especificar',
  licenseCanUseCommercially: 'Uso comercial',
  licenseCanModify: 'Se puede modificar',
  licenseCanDistribute: 'Se puede distribuir',
  licenseCanSublicense: 'Se puede sublicenciar',
  licenseCanHoldLiable: 'Se puede declarar responsable',
  licenseCannotHoldLiable: 'No puede declararse responsable',
  licenseMustIncludeCopyright: 'Debe incluir copyright',
  licenseMustIncludeLicense: 'Debe incluir licencia',
  licenseFetchDetailsFailed: 'Fallo en la obtención de los detalles de la licencia',
  imageLightboxTitle: 'Imágenes',
  imageLightBoxProgress: ':num de :total',
  nextImage: 'Siguiente imagen',
  previousImage: 'Imagen anterior ',
  screenshots: 'Capturas de pantalla',
  reloadButtonLabel: 'Recargar',
  videoQuality: 'Etiqueta de calidad de vídeo',
  videoQualityDescription: 'Esta etiqueta ayuda al usuario a identificar la calidad actual del vídeo. Por ejemplo, 1080p, 720p, HD o móvil',
  videoQualityDefaultLabel: 'Calidad :index',
  noContentTypesAvailable: 'No hay tipos de contenido disponibles',
  noContentTypesAvailableDesc: 'Su sitio tiene dificultades para conectarse a H5P.org y para listar los tipos de contenido disponibles.',
  contentTypeCacheOutdated: 'Lista de tipos de contenido obsoleta',
  contentTypeCacheOutdatedDesc: 'Su sitio tiene dificultades para conectarse a H5P.org para comprobar si hay actualizaciones del tipo de contenido. Es posible que no pueda actualizar o instalar nuevos tipos de contenido.',
  tryAgain: 'Inténtelo de nuevo',
  getHelp: 'Obtener ayuda',
  untitled: 'Sin título :libraryTitle',
  title: 'Título',
  metadata: 'Metadatos',
  addTitle: 'Añadir título',
  usedForSearchingReportsAndCopyrightInformation: 'Utilizado para búsquedas, informes e información de derechos de autor',
  metadataSharingAndLicensingInfo: 'Metadatos (información sobre uso compartido y licencias)',
  fillInTheFieldsBelow: 'Rellene los siguientes campos',
  saveMetadata: 'Guardar metadatos',
  addAuthor: 'Guardar autor',
  confirmRemoveAuthor: '¿Está seguro de que desea eliminar a este autor?',
  addNewChange: 'Añadir nuevo cambio',
  confirmDeleteChangeLog: '¿Está seguro de que desea borrar esta entrada del registro de cambios?',
  changelogDescription: 'Algunas licencias requieren que los cambios realizados en la obra original o los derivados se registren y visualicen. Usted puede registrar sus cambios aquí por razones de licencia o simplemente para permitirse a usted y a otros mantener un registro de los cambios realizados en este contenido.',
  logThisChange: 'Registrar este cambio',
  newChangeHasBeenLogged: 'Se ha registrado un nuevo cambio',
  loggedChanges: 'Cambios registrados',
  noChangesHaveBeenLogged: 'No se ha registrado ningún cambio',
  errorHeader: 'Se ha producido un error',
  errorCalculatingMaxScore: 'No se pudo calcular la puntuación máxima para este contenido. La puntuación máxima se supone que es 0. Póngse en contacto con su administrador si esto no es correcto.',
  maxScoreSemanticsMissing: 'No se pudo encontrar la semántica esperada en el contenido.',
  copyButton: 'Copiar',
  copiedButton: 'Copiado',
  pasteButton: 'Pegar',
  pasteAndReplaceButton: 'Pegar y Reemplazar',
  pasteContent: 'Reemplazar contenido',
  confirmPasteContent: 'Al hacer esto usted reemplazará el contenido actual con el contenido de su portapapeles. El contenido actual se perderá. ¿Está seguro de que quiere continuar?',
  confirmPasteButtonText: 'Reemplazar contenido',
  copyToClipboard: 'Copiar el contenido H5P al portapapeles',
  copiedToClipboard: 'El contenido se ha copiado al portapapeles',
  pasteFromClipboard: 'Pegar el contenido H5P del portapapeles',
  pasteAndReplaceFromClipboard: 'Reemplazar el contenido existente con contenido H5P del portapapeles',
  pasteNoContent: 'Ningún contenido H5P content en el portapapeles',
  pasteError: 'No se puede pegar desde el portapapeles',
  pasteContentNotSupported: 'The content in the H5P clipboard is not supported in this context',
  pasteContentRestricted: 'The content in the clipboard has been restricted on this site',
  pasteTooOld: 'The content in the H5P clipboard is of a lower version (:clip) than what is supported in this context (:local), if possible try to have the content you want to paste upgraded, copy it again and try pasting it here.',
  pasteTooNew: 'The content in the H5P clipboard is of a higher version (:clip) than what is supported in this context (:local), if possible try to have this content upgraded first, and then try pasting the content here again.',
  ok: 'OK',
  avTablistLabel: 'Insertar usando',
  tabTitleBasicFileUpload: 'Subir archivo',
  tabTitleInputLinkURL: 'Enlace/URL',
  errorTooHighVersion: 'Los parámetros contienen %used mientras que solamente %supported o anteriores están soportados.',
  errorNotSupported: 'Los parámetros contienen %used que no está soportado.',
  errorParamsBroken: 'Los parámetros están rotos.',
  libraryMissing: 'Falta la biblioteca requerida %lib.',
  scriptMissing: 'No se pudo cargar el script de actualizaciones para %lib.',
  language: 'Idioma',
  noLanguagesSupported: 'No hay idiomas soportados',
  changeLanguage: '¿Cambiar el idioma a :language?',
  thisWillPotentially: 'Esto potencialmente restablecerá todo el texto y las traducciones. No puedes deshacer esto. El contenido en sí no será cambiado. ¿Desea proceder?',
  notAllTextsChanged: 'No todos los textos fueron cambiados, solo hay una cobertura parcial para :language.',
  contributeTranslations: 'Si desea completar la traducción para :language, puede obtener información sobre <a href=":url" target="_new"> contribuir con traducciones al H5P </a>',
  unknownLibrary: 'Desafortunadamente, el tipo de contenido seleccionado \'%lib\' no está instalado en este sistema.',
  proceedButtonLabel: 'Proceder a guardar',
  enterFullscreenButtonLabel: 'Ir a pantalla completa',
  exitFullscreenButtonLabel: 'Salir de pantalla completa',
  a11yTitleShowLabel: 'Show label for AT',
  a11yTitleHideLabel: 'Hide label for AT',
  reuseSuccess: ':title was successfully imported from the H5P Hub.',
};
